@@ -6,7 +6,7 @@ use strict;
 use utf8;
 use warnings;
 
-our $VERSION = "2.303";
+our $VERSION = "2.401";
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -129,7 +129,7 @@ decoding Internationalized Domain Names (IDNs).
 IDNs use characters drawn from a large repertoire (Unicode), but
 IDNA allows the non-ASCII characters to be represented using only
 the ASCII characters already allowed in so-called host names today
-(letter-digit-hypen, C</[A-Z0-9-]/i>).
+(letter-digit-hyphen, C</[A-Z0-9-]/i>).
 
 Use this module if you just want to convert domain names (or email addresses),
 using whatever IDNA standard is the best choice at the moment.
@@ -304,7 +304,7 @@ This function currently does not handle internationalization of the local-part
 conversion for the local-part, should one be standardized.
 
 This function will convert the at sign to ASCII, i.e. to U+0040 (commercial
-at), as well as label separators.  The follwing characters are recognized as at
+at), as well as label separators.  The following characters are recognized as at
 signs: U+0040 (commercial at), U+FE6B (small commercial at) and U+FF20
 (fullwidth commercial at).
 
@@ -321,7 +321,7 @@ This function currently does not handle internationalization of the local-part
 from ASCII for the local-part, should one be standardized.
 
 This function will preserve the original version of at signs (and label
-separators). The follwing characters are recognized as at signs: U+0040
+separators). The following characters are recognized as at signs: U+0040
 (commercial at), U+FE6B (small commercial at) and U+FF20 (fullwidth commercial
 at).
 
